==> aws-cdk-lib-2.0.0-rc.6-sources.jar: software/amazon/awscdk/customresources/AwsCustomResource.java <==
package software.amazon.awscdk.customresources;

/**
 * (experimental) Defines a custom resource that is materialized using specific AWS API calls.
 * <p>
 * Use this to bridge any gap that might exist in the CloudFormation Coverage.
 * You can specify exactly which calls are invoked for the 'CREATE', 'UPDATE' and 'DELETE' life cycle events.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-06-02T09:55:53.642Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.custom_resources.AwsCustomResource")
public class AwsCustomResource extends software.constructs.Construct implements software.amazon.awscdk.services.iam.IGrantable {

    protected AwsCustomResource(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AwsCustomResource(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public AwsCustomResource(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.customresources.AwsCustomResourceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (experimental) Returns response data for the AWS SDK call as string.
     * <p>
     * Example for S3 / listBucket : 'Buckets.0.Name'
     * <p>
     * Note that you cannot use this method if <code>ignoreErrorCodesMatching</code>
     * is configured for any of the SDK calls. This is because in such a case,
     * the response data might not exist, and will cause a CloudFormation deploy time error.
     * <p>
     * @param dataPath the path to the data. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getResponseField(final @org.jetbrains.annotations.NotNull java.lang.String dataPath) {
        return software.amazon.jsii.Kernel.call(this, "getResponseField", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { java.util.Objects.requireNonNull(dataPath, "dataPath is required") });
    }

    /**
     * (experimental) Returns response data for the AWS SDK call.
     * <p>
     * Example for S3 / listBucket : 'Buckets.0.Name'
     * <p>
     * Use <code>Token.asXxx</code> to encode the returned <code>Reference</code> as a specific type or
     * use the convenience <code>getDataString</code> for string attributes.
     * <p>
     * Note that you cannot use this method if <code>ignoreErrorCodesMatching</code>
     * is configured for any of the SDK calls. This is because in such a case,
     * the response data might not exist, and will cause a CloudFormation deploy time error.
     * <p>
     * @param dataPath the path to the data. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.Reference getResponseFieldReference(final @org.jetbrains.annotations.NotNull java.lang.String dataPath) {
        return software.amazon.jsii.Kernel.call(this, "getResponseFieldReference", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.Reference.class), new Object[] { java.util.Objects.requireNonNull(dataPath, "dataPath is required") });
    }

    /**
     * (experimental) The principal to grant permissions to.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.IPrincipal getGrantPrincipal() {
        return software.amazon.jsii.Kernel.get(this, "grantPrincipal", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.IPrincipal.class));
    }

    /**
     * (experimental) A fluent builder for {@link software.amazon.awscdk.customresources.AwsCustomResource}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.customresources.AwsCustomResource> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.customresources.AwsCustomResourceProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.customresources.AwsCustomResourceProps.Builder();
        }

        /**
         * (experimental) The policy that will be added to the execution role of the Lambda function implementing this custom resource provider.
         * <p>
         * The custom resource also implements <code>iam.IGrantable</code>, making it possible
         * to use the <code>grantXxx()</code> methods.
         * <p>
         * As this custom resource uses a singleton Lambda function, it's important
         * to note the that function's role will eventually accumulate the
         * permissions/grants from all resources.
         * <p>
         * @return {@code this}
         * @see Policy.fromSdkCalls
         * @param policy The policy that will be added to the execution role of the Lambda function implementing this custom resource provider. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder policy(final software.amazon.awscdk.customresources.AwsCustomResourcePolicy policy) {
            this.props.policy(policy);
            return this;
        }

        /**
         * (experimental) A name for the Lambda function implementing this custom resource.
         * <p>
         * Default: - AWS CloudFormation generates a unique physical ID and uses that
         * ID for the function's name. For more information, see Name Type.
         * <p>
         * @return {@code this}
         * @param functionName A name for the Lambda function implementing this custom resource. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder functionName(final java.lang.String functionName) {
            this.props.functionName(functionName);
            return this;
        }

        /**
         * (experimental) Whether to install the latest AWS SDK v2. Allows to use the latest API calls documented at https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html.
         * <p>
         * The installation takes around 60 seconds.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param installLatestAwsSdk Whether to install the latest AWS SDK v2. Allows to use the latest API calls documented at https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder installLatestAwsSdk(final java.lang.Boolean installLatestAwsSdk) {
            this.props.installLatestAwsSdk(installLatestAwsSdk);
            return this;
        }

        /**
         * (experimental) The number of days log events of the Lambda function implementing this custom resource are kept in CloudWatch Logs.
         * <p>
         * Default: logs.RetentionDays.INFINITE
         * <p>
         * @return {@code this}
         * @param logRetention The number of days log events of the Lambda function implementing this custom resource are kept in CloudWatch Logs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder logRetention(final software.amazon.awscdk.services.logs.RetentionDays logRetention) {
            this.props.logRetention(logRetention);
            return this;
        }

        /**
         * (experimental) The AWS SDK call to make when the resource is created.
         * <p>
         * Default: - the call when the resource is updated
         * <p>
         * @return {@code this}
         * @param onCreate The AWS SDK call to make when the resource is created. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder onCreate(final software.amazon.awscdk.customresources.AwsSdkCall onCreate) {
            this.props.onCreate(onCreate);
            return this;
        }

        /**
         * (experimental) The AWS SDK call to make when the resource is deleted.
         * <p>
         * Default: - no call
         * <p>
         * @return {@code this}
         * @param onDelete The AWS SDK call to make when the resource is deleted. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder onDelete(final software.amazon.awscdk.customresources.AwsSdkCall onDelete) {
            this.props.onDelete(onDelete);
            return this;
        }

        /**
         * (experimental) The AWS SDK call to make when the resource is updated.
         * <p>
         * Default: - no call
         * <p>
         * @return {@code this}
         * @param onUpdate The AWS SDK call to make when the resource is updated. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder onUpdate(final software.amazon.awscdk.customresources.AwsSdkCall onUpdate) {
            this.props.onUpdate(onUpdate);
            return this;
        }

        /**
         * (experimental) Cloudformation Resource type.
         * <p>
         * Default: - Custom::AWS
         * <p>
         * @return {@code this}
         * @param resourceType Cloudformation Resource type. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder resourceType(final java.lang.String resourceType) {
            this.props.resourceType(resourceType);
            return this;
        }

        /**
         * (experimental) The execution role for the Lambda function implementing this custom resource provider.
         * <p>
         * This role will apply to all <code>AwsCustomResource</code>
         * instances in the stack. The role must be assumable by the
         * <code>lambda.amazonaws.com</code> service principal.
         * <p>
         * Default: - a new role is created
         * <p>
         * @return {@code this}
         * @param role The execution role for the Lambda function implementing this custom resource provider. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder role(final software.amazon.awscdk.services.iam.IRole role) {
            this.props.role(role);
            return this;
        }

        /**
         * (experimental) The timeout for the Lambda function implementing this custom resource.
         * <p>
         * Default: Duration.minutes(2)
         * <p>
         * @return {@code this}
         * @param timeout The timeout for the Lambda function implementing this custom resource. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder timeout(final software.amazon.awscdk.Duration timeout) {
            this.props.timeout(timeout);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.customresources.AwsCustomResource}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.customresources.AwsCustomResource build() {
            return new software.amazon.awscdk.customresources.AwsCustomResource(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/customresources/AwsCustomResource.java <==
package software.amazon.awscdk.customresources;

/**
 * Defines a custom resource that is materialized using specific AWS API calls.
 * <p>
 * Use this to bridge any gap that might exist in the CloudFormation Coverage.
 * You can specify exactly which calls are invoked for the 'CREATE', 'UPDATE' and 'DELETE' life cycle events.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * AwsCustomResource awsCustom = AwsCustomResource.Builder.create(this, "aws-custom")
 *         .onCreate(AwsSdkCall.builder()
 *                 .service("...")
 *                 .action("...")
 *                 .parameters(Map.of(
 *                         "text", "..."))
 *                 .physicalResourceId(PhysicalResourceId.of("..."))
 *                 .build())
 *         .onUpdate(AwsSdkCall.builder()
 *                 .service("...")
 *                 .action("...")
 *                 .parameters(Map.of(
 *                         "text", "...",
 *                         "resourceId", new PhysicalResourceIdReference()))
 *                 .build())
 *         .policy(AwsCustomResourcePolicy.fromSdkCalls(SdkCallsPolicyOptions.builder()
 *                 .resources(AwsCustomResourcePolicy.ANY_RESOURCE)
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:13.555Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.custom_resources.AwsCustomResource")
public class AwsCustomResource extends software.constructs.Construct implements software.amazon.awscdk.services.iam.IGrantable {

    protected AwsCustomResource(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AwsCustomResource(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public AwsCustomResource(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.customresources.AwsCustomResourceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Returns response data for the AWS SDK call as string.
     * <p>
     * Example for S3 / listBucket : 'Buckets.0.Name'
     * <p>
     * Note that you cannot use this method if <code>ignoreErrorCodesMatching</code>
     * is configured for any of the SDK calls. This is because in such a case,
     * the response data might not exist, and will cause a CloudFormation deploy time error.
     * <p>
     * @param dataPath the path to the data. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getResponseField(final @org.jetbrains.annotations.NotNull java.lang.String dataPath) {
        return software.amazon.jsii.Kernel.call(this, "getResponseField", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { java.util.Objects.requireNonNull(dataPath, "dataPath is required") });
    }

    /**
     * Returns response data for the AWS SDK call.
     * <p>
     * Example for S3 / listBucket : 'Buckets.0.Name'
     * <p>
     * Use <code>Token.asXxx</code> to encode the returned <code>Reference</code> as a specific type or
     * use the convenience <code>getDataString</code> for string attributes.
     * <p>
     * Note that you cannot use this method if <code>ignoreErrorCodesMatching</code>
     * is configured for any of the SDK calls. This is because in such a case,
     * the response data might not exist, and will cause a CloudFormation deploy time error.
     * <p>
     * @param dataPath the path to the data. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.Reference getResponseFieldReference(final @org.jetbrains.annotations.NotNull java.lang.String dataPath) {
        return software.amazon.jsii.Kernel.call(this, "getResponseFieldReference", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.Reference.class), new Object[] { java.util.Objects.requireNonNull(dataPath, "dataPath is required") });
    }

    /**
     * The principal to grant permissions to.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.IPrincipal getGrantPrincipal() {
        return software.amazon.jsii.Kernel.get(this, "grantPrincipal", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.IPrincipal.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.customresources.AwsCustomResource}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.customresources.AwsCustomResource> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.customresources.AwsCustomResourceProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.customresources.AwsCustomResourceProps.Builder();
        }

        /**
         * The policy that will be added to the execution role of the Lambda function implementing this custom resource provider.
         * <p>
         * The custom resource also implements <code>iam.IGrantable</code>, making it possible
         * to use the <code>grantXxx()</code> methods.
         * <p>
         * As this custom resource uses a singleton Lambda function, it's important
         * to note the that function's role will eventually accumulate the
         * permissions/grants from all resources.
         * <p>
         * @return {@code this}
         * @see Policy.fromSdkCalls
         * @param policy The policy that will be added to the execution role of the Lambda function implementing this custom resource provider. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder policy(final software.amazon.awscdk.customresources.AwsCustomResourcePolicy policy) {
            this.props.policy(policy);
            return this;
        }

        /**
         * A name for the Lambda function implementing this custom resource.
         * <p>
         * Default: - AWS CloudFormation generates a unique physical ID and uses that
         * ID for the function's name. For more information, see Name Type.
         * <p>
         * @return {@code this}
         * @param functionName A name for the Lambda function implementing this custom resource. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder functionName(final java.lang.String functionName) {
            this.props.functionName(functionName);
            return this;
        }

        /**
         * Whether to install the latest AWS SDK v2. Allows to use the latest API calls documented at https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html.
         * <p>
         * The installation takes around 60 seconds.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param installLatestAwsSdk Whether to install the latest AWS SDK v2. Allows to use the latest API calls documented at https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder installLatestAwsSdk(final java.lang.Boolean installLatestAwsSdk) {
            this.props.installLatestAwsSdk(installLatestAwsSdk);
            return this;
        }

        /**
         * The number of days log events of the Lambda function implementing this custom resource are kept in CloudWatch Logs.
         * <p>
         * Default: logs.RetentionDays.INFINITE
         * <p>
         * @return {@code this}
         * @param logRetention The number of days log events of the Lambda function implementing this custom resource are kept in CloudWatch Logs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder logRetention(final software.amazon.awscdk.services.logs.RetentionDays logRetention) {
            this.props.logRetention(logRetention);
            return this;
        }

        /**
         * The AWS SDK call to make when the resource is created.
         * <p>
         * Default: - the call when the resource is updated
         * <p>
         * @return {@code this}
         * @param onCreate The AWS SDK call to make when the resource is created. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onCreate(final software.amazon.awscdk.customresources.AwsSdkCall onCreate) {
            this.props.onCreate(onCreate);
            return this;
        }

        /**
         * The AWS SDK call to make when the resource is deleted.
         * <p>
         * Default: - no call
         * <p>
         * @return {@code this}
         * @param onDelete The AWS SDK call to make when the resource is deleted. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onDelete(final software.amazon.awscdk.customresources.AwsSdkCall onDelete) {
            this.props.onDelete(onDelete);
            return this;
        }

        /**
         * The AWS SDK call to make when the resource is updated.
         * <p>
         * Default: - no call
         * <p>
         * @return {@code this}
         * @param onUpdate The AWS SDK call to make when the resource is updated. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onUpdate(final software.amazon.awscdk.customresources.AwsSdkCall onUpdate) {
            this.props.onUpdate(onUpdate);
            return this;
        }

        /**
         * Cloudformation Resource type.
         * <p>
         * Default: - Custom::AWS
         * <p>
         * @return {@code this}
         * @param resourceType Cloudformation Resource type. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resourceType(final java.lang.String resourceType) {
            this.props.resourceType(resourceType);
            return this;
        }

        /**
         * The execution role for the Lambda function implementing this custom resource provider.
         * <p>
         * This role will apply to all <code>AwsCustomResource</code>
         * instances in the stack. The role must be assumable by the
         * <code>lambda.amazonaws.com</code> service principal.
         * <p>
         * Default: - a new role is created
         * <p>
         * @return {@code this}
         * @param role The execution role for the Lambda function implementing this custom resource provider. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder role(final software.amazon.awscdk.services.iam.IRole role) {
            this.props.role(role);
            return this;
        }

        /**
         * The timeout for the Lambda function implementing this custom resource.
         * <p>
         * Default: Duration.minutes(2)
         * <p>
         * @return {@code this}
         * @param timeout The timeout for the Lambda function implementing this custom resource. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder timeout(final software.amazon.awscdk.Duration timeout) {
            this.props.timeout(timeout);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.customresources.AwsCustomResource}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.customresources.AwsCustomResource build() {
            return new software.amazon.awscdk.customresources.AwsCustomResource(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
